<?php

namespace Drupal\slack_incoming\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class SlackApplicationConfigForm.
 */
class SlackApplicationConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'slack_incoming.slackapplicationconfig',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'slack_application_config_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('slack_incoming.slackapplicationconfig');
    $form['signing_secret'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Signing secret'),
      '#description' => $this->t('Slack signs the requests we send you using this secret. Confirm that each request comes from Slack by verifying its unique signature.'),
      '#maxlength' => 64,
      '#size' => 64,
      '#default_value' => $config->get('signing_secret'),
    ];
    $form['bot_user_oauth_access_token'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Bot user OAuth access token'),
      '#description' => $this->t('These tokens are automatically generated by Slack when you installed the app to your team.'),
      '#maxlength' => 64,
      '#size' => 64,
      '#default_value' => $config->get('bot_user_oauth_access_token'),
    ];
    $form['base_slack_api_url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Base Slack API URL'),
      '#description' => $this->t('The base Slack API URL. This should usually be set to the default value of <em>https://slack.com/api/</em>. Unless you have a specific reason to change this, leave it alone.'),
      '#maxlength' => 64,
      '#size' => 64,
      '#default_value' => $config->get('base_slack_api_url') ?? 'https://slack.com/api/',
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config('slack_incoming.slackapplicationconfig')
      ->set('signing_secret', $form_state->getValue('signing_secret'))
      ->set('bot_user_oauth_access_token', $form_state->getValue('bot_user_oauth_access_token'))
      ->set('base_slack_api_url', $form_state->getValue('base_slack_api_url'))
      ->save();
  }

}
